NetworkInformation

Struct NetworkInformation 

pub struct NetworkInformation {
    pub service_available: Option<bool>,
    pub signal_strength: Option<SignalStrength>,
    pub roaming: Option<bool>,
    /* private fields */
}
Network information for the Audio Gateway. Typically this represents information regarding the state of connectivity to a telephony network.

Fields

service_available: Option<bool>

Report the status of registration with the network. See HFP v1.8, Section 4.4

signal_strength: Option<SignalStrength>

Report the signal strength of the connection to the network. See the HFP v1.8, Section 4.5.

roaming: Option<bool>

Report the roaming status of the connection to the network. See HFP v1.8, Section 4.6